Copydog
-------

Copydog converts issues between Redmine and Trello on the fly.
It's a small third-party daemon, monitoring changes in both systems and keeping
them in sync as much as possible.

Docs: http://copydog.readthedocs.org/